% Number the equations.
%
% function retobj = numbereqns (self,varargin)
%
%    Call as:
%      f=numbereqns(f);
%    or
%      f=numbereqns(f,n);
% where
% n=either a scalar, or an array of equation numbers.
% 
% Note that we're assigning to f: f changes inside this function!
%
% The free components in the field are numbered consecutively.
% No effort is made to optimize the numbering in any way.
%
function retobj = numbereqns (self,varargin)
    invalid_eqnum = get(sysmat, 'invalid_eqnum');
    [nfens,dim] = size(self.values);
    arg= [];
    if nargin > 1
        arg=varargin{1};
    end
    if ~isempty(arg)
        if prod(size(arg))==1
            self.neqns = arg;
        else
            self.eqnums=arg;
            self.neqns =max(max(self.eqnums));
            retobj = self;
            return;
        end
    else
        self.neqns = 0;
    end
    % regular numbering
    for i=1:nfens
        for j=1:dim
            if (~self.is_prescribed(i,j))
                self.neqns = self.neqns + 1;
                self.eqnums(i,j) = self.neqns;
            else
                self.eqnums(i,j) = invalid_eqnum;
            end
        end
    end
    retobj = self;
end


